"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cacheConfig_1 = require("./cacheConfig");
const logger_1 = require("../logger");
const backfill = __importStar(require("backfill/lib/api"));
const path_1 = __importDefault(require("path"));
const hashes = {};
const cacheHits = {};
exports.cacheHits = cacheHits;
async function cacheHash(info, config) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, config);
    const backfillLogger = backfill.makeLogger("error", process.stdout, process.stderr);
    const name = info.name;
    backfillLogger.setName(name);
    try {
        const hash = await backfill.computeHash(packagePath, backfillLogger, config.command.join(" ") + config.args.join(" "), cacheConfig);
        hashes[info.name] = hash;
    }
    catch (e) {
        logger_1.logger.error(`${info.name} computeHash`, e);
    }
}
exports.cacheHash = cacheHash;
async function cacheFetch(info, config) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, config);
    const backfillLogger = backfill.makeLogger("error", process.stdout, process.stderr);
    const hash = hashes[info.name];
    try {
        const cacheHit = await backfill.fetch(packagePath, hash, backfillLogger, cacheConfig);
        cacheHits[info.name] = cacheHit;
    }
    catch (e) {
        logger_1.logger.error(`${info.name} fetchBackfill`, e);
    }
}
exports.cacheFetch = cacheFetch;
async function cachePut(info, config) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, config);
    const backfillLogger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const hash = hashes[info.name];
    try {
        await backfill.put(packagePath, hash, backfillLogger, cacheConfig);
    }
    catch (e) {
        // sometimes outputGlob don't match any files, so skipping this
    }
}
exports.cachePut = cachePut;
