"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cosmiconfig_1 = require("cosmiconfig");
const workspace_tools_1 = require("workspace-tools");
const args_1 = require("../args");
const os_1 = __importDefault(require("os"));
function getConfig(cwd) {
    // Verify presence of git
    const root = workspace_tools_1.findGitRoot(cwd);
    if (!root) {
        throw new Error("This must be called inside a git-controlled repo");
    }
    // Search for lage.config.js file
    const ConfigModuleName = "lage";
    const configResults = cosmiconfig_1.cosmiconfigSync(ConfigModuleName).search(root || cwd);
    // Parse CLI args
    const parsedArgs = args_1.parseArgs();
    const command = parsedArgs._;
    // deps should be default true, unless exclusively turned off with '--no-deps' or from config file with "deps: false"
    const deps = parsedArgs.deps === false
        ? false
        : (configResults === null || configResults === void 0 ? void 0 : configResults.config.deps) === false
            ? false
            : true;
    return {
        args: args_1.getPassThroughArgs(parsedArgs),
        cache: parsedArgs.cache === false ? false : true,
        cacheOptions: (configResults === null || configResults === void 0 ? void 0 : configResults.config.cacheOptions) || {},
        command,
        concurrency: parsedArgs.concurrency || (configResults === null || configResults === void 0 ? void 0 : configResults.config.concurrency) ||
            os_1.default.cpus().length - 1,
        deps,
        ignore: parsedArgs.ignore || (configResults === null || configResults === void 0 ? void 0 : configResults.config.ignoreGlob) || [],
        node: parsedArgs.node ? args_1.arrifyArgs(parsedArgs.node) : [],
        npmClient: (configResults === null || configResults === void 0 ? void 0 : configResults.config.npmClient) || "npm",
        pipeline: (configResults === null || configResults === void 0 ? void 0 : configResults.config.pipeline) || {},
        profile: parsedArgs.profile,
        scope: parsedArgs.scope || (configResults === null || configResults === void 0 ? void 0 : configResults.config.scope) || [],
        since: parsedArgs.since || undefined,
        verbose: parsedArgs.verbose,
    };
}
exports.getConfig = getConfig;
