"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const backfill_1 = require("../cache/backfill");
const formatDuration_1 = require("../logger/formatDuration");
const logger_1 = require("../logger");
const cacheTasks_1 = require("../cache/cacheTasks");
async function taskWrapper(pkg, task, fn, context) {
    const { profiler, measures } = context;
    const logger = logger_1.taskLogger(pkg, task);
    const start = process.hrtime();
    if (!backfill_1.cacheHits[pkg]) {
        if (!cacheTasks_1.isCacheTask(task)) {
            logger.info("started");
        }
        try {
            await profiler.run(() => fn(), `${pkg}.${task}`);
            const duration = process.hrtime(start);
            if (!cacheTasks_1.isCacheTask(task)) {
                measures.taskStats.push({
                    pkg,
                    task,
                    start,
                    duration,
                    status: "success",
                });
                logger.info(`done - took ${formatDuration_1.formatDuration(duration)}`);
            }
        }
        catch (e) {
            measures.failedTask = { pkg, task };
            const duration = process.hrtime(start);
            measures.taskStats.push({ pkg, task, start, duration, status: "failed" });
            throw e;
        }
    }
    else if (!cacheTasks_1.isCacheTask(task)) {
        const duration = process.hrtime(start);
        measures.taskStats.push({ pkg, task, start, duration, status: "skipped" });
        logger.info("skipped");
    }
}
exports.taskWrapper = taskWrapper;
